@Generated(value="jsii-pacmak/1.77.0 (build 3e5fa88)", date="2023-03-14T15:05:01.428Z") @Stability(value=Stable) public class AdotLambdaLayerPythonSdkVersion extends software.amazon.jsii.JsiiObject
Example:
// The code below shows an example of how to instantiate this type. // The values are placeholders you should change. import software.amazon.awscdk.services.lambda.*; AdotLambdaLayerPythonSdkVersion adotLambdaLayerPythonSdkVersion = AdotLambdaLayerPythonSdkVersion.LATEST;
| Modifier and Type | Field and Description |
|---|---|
static AdotLambdaLayerPythonSdkVersion |
LATEST
The latest layer version available in this CDK version.
|
static AdotLambdaLayerPythonSdkVersion |
V1_13_0
Version 1.13.0.
|
| Modifier | Constructor and Description |
|---|---|
protected |
AdotLambdaLayerPythonSdkVersion(software.amazon.jsii.JsiiObject.InitializationMode initializationMode) |
protected |
AdotLambdaLayerPythonSdkVersion(software.amazon.jsii.JsiiObjectRef objRef) |
| Modifier and Type | Method and Description |
|---|---|
protected String |
getLayerVersion() |
String |
layerArn(software.constructs.IConstruct scope,
Architecture architecture)
The ARN of the Lambda layer.
|
jsiiAsyncCall, jsiiAsyncCall, jsiiCall, jsiiCall, jsiiGet, jsiiGet, jsiiSet, jsiiStaticCall, jsiiStaticCall, jsiiStaticGet, jsiiStaticGet, jsiiStaticSet, jsiiStaticSet@Stability(value=Stable) public static final AdotLambdaLayerPythonSdkVersion LATEST
New versions could introduce incompatible changes. Make sure to test them before deploying to production.
@Stability(value=Stable) public static final AdotLambdaLayerPythonSdkVersion V1_13_0
protected AdotLambdaLayerPythonSdkVersion(software.amazon.jsii.JsiiObjectRef objRef)
protected AdotLambdaLayerPythonSdkVersion(software.amazon.jsii.JsiiObject.InitializationMode initializationMode)
@Stability(value=Stable) @NotNull public String layerArn(@NotNull software.constructs.IConstruct scope, @NotNull Architecture architecture)
scope - The binding scope. This parameter is required.architecture - The architecture of the Lambda layer (either X86_64 or ARM_64). This parameter is required.@Stability(value=Stable) @NotNull protected String getLayerVersion()
Copyright © 2023. All rights reserved.