@Stability(value=Stable) @Internal public static final class CfnBot.PostDialogCodeHookInvocationSpecificationProperty.Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnBot.PostDialogCodeHookInvocationSpecificationProperty
CfnBot.PostDialogCodeHookInvocationSpecificationPropertysoftware.amazon.jsii.JsiiObject.InitializationModeCfnBot.PostDialogCodeHookInvocationSpecificationProperty.Builder, CfnBot.PostDialogCodeHookInvocationSpecificationProperty.Jsii$Proxy| Modifier | Constructor and Description |
|---|---|
protected |
Jsii$Proxy(CfnBot.PostDialogCodeHookInvocationSpecificationProperty.Builder builder)
Constructor that initializes the object based on literal property values passed by the
CfnBot.AdvancedRecognitionSettingProperty.Builder. |
protected |
Jsii$Proxy(software.amazon.jsii.JsiiObjectRef objRef)
Constructor that initializes the object based on values retrieved from the JsiiObject.
|
| Modifier and Type | Method and Description |
|---|---|
com.fasterxml.jackson.databind.JsonNode |
$jsii$toJson() |
boolean |
equals(Object o) |
Object |
getFailureConditional()
A list of conditional branches to evaluate after the dialog code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
|
Object |
getFailureNextStep()
Specifies the next step the bot runs after the dialog code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
|
Object |
getFailureResponse()
Specifies a list of message groups that Amazon Lex uses to respond the user input when the code hook fails.
|
Object |
getSuccessConditional()
A list of conditional branches to evaluate after the dialog code hook finishes successfully.
|
Object |
getSuccessNextStep()
Specifics the next step the bot runs after the dialog code hook finishes successfully.
|
Object |
getSuccessResponse()
Specifies a list of message groups that Amazon Lex uses to respond when the code hook succeeds.
|
Object |
getTimeoutConditional()
A list of conditional branches to evaluate if the code hook times out.
|
Object |
getTimeoutNextStep()
Specifies the next step that the bot runs when the code hook times out.
|
Object |
getTimeoutResponse()
Specifies a list of message groups that Amazon Lex uses to respond to the user input when the code hook times out.
|
int |
hashCode() |
jsiiAsyncCall, jsiiAsyncCall, jsiiCall, jsiiCall, jsiiGet, jsiiGet, jsiiSet, jsiiStaticCall, jsiiStaticCall, jsiiStaticGet, jsiiStaticGet, jsiiStaticSet, jsiiStaticSetclone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitbuilderprotected Jsii$Proxy(software.amazon.jsii.JsiiObjectRef objRef)
objRef - Reference to the JSII managed object.protected Jsii$Proxy(CfnBot.PostDialogCodeHookInvocationSpecificationProperty.Builder builder)
CfnBot.AdvancedRecognitionSettingProperty.Builder.public final Object getFailureConditional()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetFailureConditional in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getFailureNextStep()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetFailureNextStep in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getFailureResponse()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetFailureResponse in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getSuccessConditional()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetSuccessConditional in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getSuccessNextStep()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetSuccessNextStep in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getSuccessResponse()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetSuccessResponse in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getTimeoutConditional()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetTimeoutConditional in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getTimeoutNextStep()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetTimeoutNextStep in interface CfnBot.PostDialogCodeHookInvocationSpecificationPropertypublic final Object getTimeoutResponse()
CfnBot.PostDialogCodeHookInvocationSpecificationPropertygetTimeoutResponse in interface CfnBot.PostDialogCodeHookInvocationSpecificationProperty@Internal public com.fasterxml.jackson.databind.JsonNode $jsii$toJson()
$jsii$toJson in interface software.amazon.jsii.JsiiSerializableCopyright © 2023. All rights reserved.